@@ -1,8 +1,6 @@
 from bt import backend_to_check, gnome, kde
-from pyscreenshot.util import py2
 
-# no jeepney for py2
-if gnome() and not py2():
+if gnome():
 
     def test_gnome_dbus():
         assert not kde()
