@@ -1,8 +1,6 @@
 from bt import backend_to_check, gnome, kde
-from pyscreenshot.util import py2
 
-# no jeepney for py2
-if kde() and not py2():
+if kde():
 
     def test_kwin_dbus():
         assert not gnome()
