@@ -1,5 +1,5 @@
+from bt import backend_to_check
 from pyscreenshot.util import platform_is_osx
-from ref import backend_to_check
 
 if platform_is_osx():
 
