@@ -8,10 +8,12 @@ if check_import("gi"):
 
         # Arch: AttributeError: module 'gi' has no attribute 'require_version'
         try:
-            gi.require_version
+            gi.require_version("Gdk", "3.0")
             ok = True
         except AttributeError:
             pass
+        except ValueError:
+            pass
 if ok:
 
     def test_pygdk3():
